@@ -131,4 +131,11 @@ class Timer:
                 print(f'Total time        : {total_elapsed}')
         else: return total_elapsed
 
-timer = Timer()
\ No newline at end of file
+timer = Timer()
+
+def import_file_as_module(path):
+    from importlib import import_module
+    if '.py' in path: path = path.rsplit('.', 1)[0]
+    if '/' in path: path, fname = path.rsplit('/', 1)
+    else: path, fname = None, path
+    return import_module(fname, path)
\ No newline at end of file
